@@ -66,7 +66,6 @@ class ZenSpamhaus(Provider):
 _BASE_PROVIDERS = [
     'aspews.ext.sorbs.net',
     'b.barracudacentral.org',
-    'bl.deadbeef.com',
     'bl.spamcop.net',
     'blackholes.five-ten-sg.com',
     'blacklist.woody.ch',
@@ -75,11 +74,9 @@ _BASE_PROVIDERS = [
     'combined.abuse.ch',
     'combined.rbl.msrbl.net',
     'db.wpbl.info',
-    'dnsbl-1.uceprotect.net',
     'dnsbl-2.uceprotect.net',
     'dnsbl-3.uceprotect.net',
     'dnsbl.cyberlogic.net',
-    'dnsbl.inps.de',
     'dnsbl.sorbs.net',
     'drone.abuse.ch',
     'dul.dnsbl.sorbs.net',
@@ -153,4 +150,4 @@ _DOMAIN_PROVIDERS = [
 ]
 
 BASE_PROVIDERS = [Provider(host) for host in _BASE_PROVIDERS] + [ZenSpamhaus()]
-BASE_DOMAIN_PROVIDERS = [Provider(host) for host in _DOMAIN_PROVIDERS] + [DblSpamhaus()]
\ No newline at end of file
+BASE_DOMAIN_PROVIDERS = [Provider(host) for host in _DOMAIN_PROVIDERS] + [DblSpamhaus()]
